Editing posts
=============

.. admonition:: Permissions

   You need the “can edit others’ posts” permission to edit posts of other
   users.  You can always edit your own posts.

The *Edit* view lets you make modifications to posts.

The topmost field is the title of the post.  You can always change it.
Remember that the post URL will **not** change, as it is set in stone during post
creation.

The next line features four fields: date, author, tags and category.

.. admonition:: Permissions

   Post author may be changed only if you have the “transfer post authorship”
   permission.

Tags are comma-separated.  A post can have only **one** category.  Many date
formats are accepted.  The default format used is ``yyyy-mm-dd hh:mm:ss UTC±hh:mm``,
(the last element being the timezone) but if you fill in your own format, it
will usually work.

The next line is the editor toolbar (which also features the Save button).  Underneath
it, the post content is displayed in a box.  You can edit it in any way you
like.  The editor handles formatting for you, but you can click the ``</>`` button
to edit the HTML source.
